bread.contrib.activities package
================================

.. automodule:: bread.contrib.activities
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   bread.contrib.activities.examples
   bread.contrib.activities.management

Submodules
----------

bread.contrib.activities.models module
--------------------------------------

.. automodule:: bread.contrib.activities.models
   :members:
   :undoc-members:
   :show-inheritance:

bread.contrib.activities.urls module
------------------------------------

.. automodule:: bread.contrib.activities.urls
   :members:
   :undoc-members:
   :show-inheritance:
